from circle.resources.abstract import RetrievableAPIResource
from circle.resources.abstract import ListableAPIResource
from circle.resources.abstract import CreateableAPIResource


class Transfer(CreateableAPIResource, ListableAPIResource):
    """
    https://developers.circle.com/reference#payouts-transfers-create
    """

    OBJECT_NAME = "transfers"  # The object name as it maps to the API resource.



from circle.resources.abstract import CreateableAPIResource
from circle.resources.abstract import RetrievableAPIResource


class Wire(CreateableAPIResource, RetrievableAPIResource):

    OBJECT_NAME = "banks.wires"



from circle.resources.abstract import CreateableAPIResource
from circle.resources.abstract import RetrievableAPIResource


class Ach(CreateableAPIResource, RetrievableAPIResource):

    OBJECT_NAME = "banks.ach"



from circle.resources.abstract import RetrievableAPIResource
from circle.resources.abstract import ListableAPIResource


class PublicKey(ListableAPIResource):
    """
    https://developers.circle.com/reference/encryption
    """

    OBJECT_NAME = "encryption.public"  # The object name as it maps to the API resource.
